@@ -7,7 +7,7 @@ RDF::Trine::Pattern - Class for basic graph patterns
 
 =head1 VERSION
 
-This document describes RDF::Trine::Pattern version 1.011
+This document describes RDF::Trine::Pattern version 1.019
 
 =cut
 
@@ -29,7 +29,7 @@ use RDF::Trine qw(iri);
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '1.011';
+	$VERSION	= '1.019';
 }
 
 ######################################################################
@@ -200,9 +200,12 @@ merge_patterns >> in that order.
 
 sub sort_for_join_variables {
 	my $self	= shift;
+	return $self if (scalar $self->triples == 1);
+
 	my $class	= ref($self);
 	my $l		= Log::Log4perl->get_logger("rdf.trine.pattern");
 	$l->debug('Reordering ' . scalar $self->triples . ' triples for heuristical optimizations');
+
 	my @sorted_triple_patterns = $self->subgroup;
 
 	my @patterns;
@@ -382,7 +385,7 @@ sub _hsp_heuristic_1_4_triple_pattern_order { # Heuristic 1 and 4 of HSP
 # spo: 8
 # sao: 10
 # s?l: 14
-# s?p: 16
+# s?o: 16
 # ?pl: 25
 # ?po: 27
 # sp?: 30
